#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'documentation.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "/pub/devel/octave/octave-6.4.0-1.x86_64/src/octave-6.4.0/libgui/src/documentation.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'documentation.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__documentation_browser_t {
    QByteArrayData data[11];
    char stringdata0[140];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__documentation_browser_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__documentation_browser_t qt_meta_stringdata_octave__documentation_browser = {
    {
QT_MOC_LITERAL(0, 0, 29), // "octave::documentation_browser"
QT_MOC_LITERAL(1, 30, 20), // "handle_index_clicked"
QT_MOC_LITERAL(2, 51, 0), // ""
QT_MOC_LITERAL(3, 52, 3), // "url"
QT_MOC_LITERAL(4, 56, 7), // "keyword"
QT_MOC_LITERAL(5, 64, 15), // "notice_settings"
QT_MOC_LITERAL(6, 80, 19), // "const gui_settings*"
QT_MOC_LITERAL(7, 100, 8), // "settings"
QT_MOC_LITERAL(8, 109, 7), // "zoom_in"
QT_MOC_LITERAL(9, 117, 8), // "zoom_out"
QT_MOC_LITERAL(10, 126, 13) // "zoom_original"

    },
    "octave::documentation_browser\0"
    "handle_index_clicked\0\0url\0keyword\0"
    "notice_settings\0const gui_settings*\0"
    "settings\0zoom_in\0zoom_out\0zoom_original"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__documentation_browser[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   44,    2, 0x0a /* Public */,
       1,    1,   49,    2, 0x2a /* Public | MethodCloned */,
       5,    1,   52,    2, 0x0a /* Public */,
       8,    0,   55,    2, 0x0a /* Public */,
       9,    0,   56,    2, 0x0a /* Public */,
      10,    0,   57,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::QUrl, QMetaType::QString,    3,    4,
    QMetaType::Void, QMetaType::QUrl,    3,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void octave::documentation_browser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        documentation_browser *_t = static_cast<documentation_browser *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->handle_index_clicked((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 1: _t->handle_index_clicked((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 2: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
        case 3: _t->zoom_in(); break;
        case 4: _t->zoom_out(); break;
        case 5: _t->zoom_original(); break;
        default: ;
        }
    }
}

const QMetaObject octave::documentation_browser::staticMetaObject = {
    { &QTextBrowser::staticMetaObject, qt_meta_stringdata_octave__documentation_browser.data,
      qt_meta_data_octave__documentation_browser,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::documentation_browser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::documentation_browser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__documentation_browser.stringdata0))
        return static_cast<void*>(this);
    return QTextBrowser::qt_metacast(_clname);
}

int octave::documentation_browser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTextBrowser::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
struct qt_meta_stringdata_octave__documentation_t {
    QByteArrayData data[34];
    char stringdata0[481];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__documentation_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__documentation_t qt_meta_stringdata_octave__documentation = {
    {
QT_MOC_LITERAL(0, 0, 21), // "octave::documentation"
QT_MOC_LITERAL(1, 22, 18), // "show_single_result"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 15), // "notice_settings"
QT_MOC_LITERAL(4, 58, 19), // "const gui_settings*"
QT_MOC_LITERAL(5, 78, 8), // "settings"
QT_MOC_LITERAL(6, 87, 13), // "copyClipboard"
QT_MOC_LITERAL(7, 101, 14), // "pasteClipboard"
QT_MOC_LITERAL(8, 116, 9), // "selectAll"
QT_MOC_LITERAL(9, 126, 8), // "load_ref"
QT_MOC_LITERAL(10, 135, 4), // "name"
QT_MOC_LITERAL(11, 140, 11), // "registerDoc"
QT_MOC_LITERAL(12, 152, 13), // "unregisterDoc"
QT_MOC_LITERAL(13, 166, 13), // "activate_find"
QT_MOC_LITERAL(14, 180, 13), // "global_search"
QT_MOC_LITERAL(15, 194, 21), // "global_search_started"
QT_MOC_LITERAL(16, 216, 22), // "global_search_finished"
QT_MOC_LITERAL(17, 239, 4), // "hits"
QT_MOC_LITERAL(18, 244, 13), // "filter_update"
QT_MOC_LITERAL(19, 258, 10), // "expression"
QT_MOC_LITERAL(20, 269, 21), // "filter_update_history"
QT_MOC_LITERAL(21, 291, 4), // "find"
QT_MOC_LITERAL(22, 296, 8), // "backward"
QT_MOC_LITERAL(23, 305, 13), // "find_backward"
QT_MOC_LITERAL(24, 319, 24), // "find_forward_from_anchor"
QT_MOC_LITERAL(25, 344, 4), // "text"
QT_MOC_LITERAL(26, 349, 22), // "record_anchor_position"
QT_MOC_LITERAL(27, 372, 29), // "handle_cursor_position_change"
QT_MOC_LITERAL(28, 402, 28), // "handle_search_result_clicked"
QT_MOC_LITERAL(29, 431, 3), // "url"
QT_MOC_LITERAL(30, 435, 20), // "update_history_menus"
QT_MOC_LITERAL(31, 456, 13), // "open_hist_url"
QT_MOC_LITERAL(32, 470, 8), // "QAction*"
QT_MOC_LITERAL(33, 479, 1) // "a"

    },
    "octave::documentation\0show_single_result\0"
    "\0notice_settings\0const gui_settings*\0"
    "settings\0copyClipboard\0pasteClipboard\0"
    "selectAll\0load_ref\0name\0registerDoc\0"
    "unregisterDoc\0activate_find\0global_search\0"
    "global_search_started\0global_search_finished\0"
    "hits\0filter_update\0expression\0"
    "filter_update_history\0find\0backward\0"
    "find_backward\0find_forward_from_anchor\0"
    "text\0record_anchor_position\0"
    "handle_cursor_position_change\0"
    "handle_search_result_clicked\0url\0"
    "update_history_menus\0open_hist_url\0"
    "QAction*\0a"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__documentation[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      23,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  129,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,  132,    2, 0x0a /* Public */,
       6,    0,  135,    2, 0x0a /* Public */,
       7,    0,  136,    2, 0x0a /* Public */,
       8,    0,  137,    2, 0x0a /* Public */,
       9,    1,  138,    2, 0x0a /* Public */,
      11,    1,  141,    2, 0x0a /* Public */,
      12,    1,  144,    2, 0x0a /* Public */,
      13,    0,  147,    2, 0x08 /* Private */,
      14,    0,  148,    2, 0x08 /* Private */,
      15,    0,  149,    2, 0x08 /* Private */,
      16,    1,  150,    2, 0x08 /* Private */,
      18,    1,  153,    2, 0x08 /* Private */,
      20,    0,  156,    2, 0x08 /* Private */,
      21,    1,  157,    2, 0x08 /* Private */,
      21,    0,  160,    2, 0x28 /* Private | MethodCloned */,
      23,    0,  161,    2, 0x08 /* Private */,
      24,    1,  162,    2, 0x08 /* Private */,
      26,    0,  165,    2, 0x08 /* Private */,
      27,    0,  166,    2, 0x08 /* Private */,
      28,    1,  167,    2, 0x08 /* Private */,
      30,    0,  170,    2, 0x08 /* Private */,
      31,    1,  171,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QUrl,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::QString,   19,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   22,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   25,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl,   29,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 32,   33,

       0        // eod
};

void octave::documentation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        documentation *_t = static_cast<documentation *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->show_single_result((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 1: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
        case 2: _t->copyClipboard(); break;
        case 3: _t->pasteClipboard(); break;
        case 4: _t->selectAll(); break;
        case 5: _t->load_ref((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->registerDoc((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->unregisterDoc((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->activate_find(); break;
        case 9: _t->global_search(); break;
        case 10: _t->global_search_started(); break;
        case 11: _t->global_search_finished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->filter_update((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->filter_update_history(); break;
        case 14: _t->find((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->find(); break;
        case 16: _t->find_backward(); break;
        case 17: _t->find_forward_from_anchor((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 18: _t->record_anchor_position(); break;
        case 19: _t->handle_cursor_position_change(); break;
        case 20: _t->handle_search_result_clicked((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 21: _t->update_history_menus(); break;
        case 22: _t->open_hist_url((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (documentation::*_t)(const QUrl & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&documentation::show_single_result)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject octave::documentation::staticMetaObject = {
    { &QSplitter::staticMetaObject, qt_meta_stringdata_octave__documentation.data,
      qt_meta_data_octave__documentation,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::documentation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::documentation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__documentation.stringdata0))
        return static_cast<void*>(this);
    return QSplitter::qt_metacast(_clname);
}

int octave::documentation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSplitter::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void octave::documentation::show_single_result(const QUrl & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
